summaryrefslogtreecommitdiffstats
path: root/chrome/installer/util/master_preferences.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/installer/util/master_preferences.h')
-rw-r--r--chrome/installer/util/master_preferences.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/chrome/installer/util/master_preferences.h b/chrome/installer/util/master_preferences.h
index 335a4ad..a809c97 100644
--- a/chrome/installer/util/master_preferences.h
+++ b/chrome/installer/util/master_preferences.h
@@ -65,12 +65,14 @@ extern const wchar_t kVerboseLogging[];
const wchar_t kDefaultMasterPrefs[] = L"master_preferences";
// Gets the value of given boolean preference |name| from |prefs| dictionary
// which is assumed to contain a dictionary named "distribution".
bool GetDistroBooleanPreference(const DictionaryValue* prefs,
- const std::wstring& name);
+ const std::wstring& name,
+ bool* value);
-// This function gets ping delay (ping_delay in the sample above) from master
-// preferences.
+// This function gets value of an integer preference from master
+// preferences. Returns true if the value is read successfully, otherwise false.
bool GetDistroIntegerPreference(const DictionaryValue* prefs,
const std::wstring& name,
int* value);
@@ -65,12 +65,14 @@ extern const wchar_t kVerboseLogging[];
const wchar_t kDefaultMasterPrefs[] = L"master_preferences";
// Gets the value of given boolean preference |name| from |prefs| dictionary
-// which is assumed to contain a dictionary named "distribution".
+// which is assumed to contain a dictionary named "distribution". Returns
+// true if the value is read successfully, otherwise false.
bool GetDistroBooleanPreference(const DictionaryValue* prefs,